@@ -182,8 +182,9 @@ int  main(int argc, char **argv)
   checkInterval=atoi(GetConfValue("UselessCheckInterval"));
   uselessCheckTime=time(NULL);
   DelUselessSessions();
+  DelOldMacInfoInWorkDb();
+  DelOldSessionLogInMngDb();
 
-  DelOldMacInfoInWorkDb(); /**********************************/
   /*** enter infinite loop of packet inspection ***/
   while(1){
 
@@ -218,6 +219,7 @@ int  main(int argc, char **argv)
 	uselessCheckTime = time(NULL);
 	DelUselessSessions();
 	DelOldMacInfoInWorkDb();
+	DelOldSessionLogInMngDb();
       }
 
       /* and return to loop top */
@@ -244,7 +246,7 @@ int  main(int argc, char **argv)
     /* if the address is included in watchlist, report the detection */
     /* watchlist is the address list needing specific reporting */
     /* (e.g., suspicion of illegal access). no need for normal operation */
-    if(IsFoundInWatchlistCache(macAddress)==TRUE){
+    if(IsAddrFoundInWatchlistCache(macAddress)==TRUE){
       err_msg_warn("WARN: find mac=%s ip=%s", macAddress, ipAddress);
     }
 
@@ -313,6 +315,7 @@ int  main(int argc, char **argv)
       uselessCheckTime = time(NULL);
       DelUselessSessions();
       DelOldMacInfoInWorkDb();
+      DelOldSessionLogInMngDb();
     }
   }
   /*** end of infinite loop ***/
