@@ -173,8 +173,12 @@ int ReFormatMacAddr(char* macAddr);
 int InitMngDb(void);
 int QueryMacFromMngDb(char* macAddress, char* userid, char* extraid);
 void CloseMngDb(void);
+int PutCloseToMngDb(char* macAddress);
+int PutOpenToMngDb(char* macAddress);
 int GetNextRecordFromWatchlistTableInMngDb(char* macAddress);
 int IsAllFoundInWatchlistTable(void);
+int DelOldSessionLogInMngDb(void);
+int IsTableFoundInMngDb(char* table);
 
 /* workdb.c */
 int SetupSqliteBusyTimeoutValue(void);
@@ -191,7 +195,7 @@ int GetSessionTableFromWorkDb(DB* sessionTable);
 int PutMacInfoToWorkDb(char* macAddress, int ttl, int isNat);
 int GetMacInfoFromWorkDb(char* macAddress, char* detectTimeStr, int* pTtl);
 int IsActiveRuleInWorkDb(int ruleNumber);
-int IsFoundMacIpPairInWorkDb(char* macAddress, char* ipAddress);
+int IsMacIpPairFoundInWorkDb(char* macAddress, char* ipAddress);
 int PutMacIpPairToWorkDb(char* macAddress, char* ipAddress);
 int DelMacIpPairsInWorkDb(char* macAddress);
 int DelOldMacInfoInWorkDb(void);
@@ -236,7 +240,7 @@ int AddMacCacheItem(char* macAddress, char* userId, char* extraId, int found);
 /* watchlistcache.c */
 void InitWatchlistCache(void);
 int AddWatchlistCacheItem(char* macAddress);
-int IsFoundInWatchlistCache(char* macAddress);
+int IsAddrFoundInWatchlistCache(char* macAddress);
 void FreeWatchlistCache(void);
 
 /* signal.c */
