@@ -189,6 +189,7 @@ int CountMacModifyPerDayInMngDb(char* userId, char* extraId, char* macAddress);
 int DelMacAddrFromMngDb(char* macAddr);
 int RenewMacAddrInMngDb(char* macAddr);
 int PauseMacAddrInMngDb(char* macAddr);
+int GetNextUsageLogFromMngDb(char* userId, char* extraId, char* macAddr, char* deviceName, char* openTime, char* closeTime, char* gatewayName);
 int GetNextMailAddressFromMngDb(char* mailAddress, char* limitDate, char*device);
 int GetTimeRangeToShowLog(char* beginTime, char* endTime, int* dateCount);
 int RenameDeviceNameInMngDb(char* macAddr, char* nameStr);
@@ -196,6 +197,7 @@ int RenameMailAddressInMngDb(char* macAddr, char* mailStr);
 int RegOrUpNobodyMacAddr(char* macAddress);
 int IsMacAddrStatusInactiveInMngDb(char* macAddress);
 int DoesMacAddrBelongToUser(char* macAddr, char* userId, char* extraId);
+int IsTableFoundInMngDb(char* table);
 
 /* workdb.c */
 int SetupSqliteBusyTimeoutValue(void);
@@ -244,6 +246,7 @@ int IsCorrectCookie(char* cookie, int userType);
 int AnalyzeUpdateRequestAndExecute(char *content, char* userId, char* extraId);
 int PutUpdatePageToClient(char *language, char* userId, char* extraId, int ownUpdate, char* redirectedUrl);
 void PutMacListToClient(char *userId, char* extraId);
+void PutUsageLogToClient(char *userId, char* extraId, char* language);
 int IsAccessedFromAllowableAgent(void);
 
 /* messages.c */
