@@ -30,9 +30,9 @@ Email: watanaby@is.saga-u.ac.jp
 /* fd : file descriptor                          */
 /* fmt : format to write                         */
 /* ... : terms to write                          */
+/* usage is same as fprintf                      */
 /*************************************************/
-void Writefmt(int fd, const char *fmt, ...)
-{
+void Writefmt(int fd, const char *fmt, ...){
   char	buff[BUFFMAXLN];
   va_list     ap;
   int nchar, nwrt;
@@ -47,9 +47,10 @@ void Writefmt(int fd, const char *fmt, ...)
   return;
 }
 
-
-void WritefmtSSL(SSL *fd, const char *fmt, ...)
-{
+/***********************************************/
+/* SSL version of WriteFmt                     */
+/***********************************************/
+void WritefmtSSL(SSL *fd, const char *fmt, ...){
   char	buff[BUFFMAXLN];
   va_list     ap;
   int nchar, nwrt;
@@ -71,20 +72,18 @@ void WritefmtSSL(SSL *fd, const char *fmt, ...)
 /*   vptr: input buffer pointer                       */
 /*   maxlen: buffer length                            */
 /*                                                    */
-/* the chars terminated with EOL or EOF is read in    */
-/* ## this function assumes two EOL chars [CR LF]     */ 
-/*  CRLF is not read in and skipped                   */
-/* [abcdCRLFefghCRLF] => read[abcd],left[efghCRLF]    */
+/* read the string terminated with EOL or EOF         */
+/* # this function assumes two EOL chars [CR LF]      */ 
+/*  CRLF is not stored into buffer and is skipped     */
+/* [abcdCRLFefghCRLF] => store[abcd],remain[efghCRLF] */
 /*                                                    */
 /* return value                                       */
-/*    plus value means the count of chars to read     */
+/*    plus value means the count of read-in chars     */
 /*    value 0 means NULL line (no-chars & CRLF)       */
 /*    value -1 means error (errno is set)             */
 /*    value -2 means EOF (no-chars & EOF)             */ 
 /******************************************************/
-ssize_t
-readln(int fd, void *vptr, size_t maxlen)
-{
+ssize_t readln(int fd, void *vptr, size_t maxlen){
   ssize_t	n, rc;
   char	*ptr,c;
 
@@ -117,10 +116,10 @@ readln(int fd, void *vptr, size_t maxlen)
   return(n);
 }
 
-
-ssize_t
-readlnSSL(SSL *fd, void *vptr, size_t maxlen)
-{
+/***********************************************/
+/* SSL version of readIn                       */
+/***********************************************/
+ssize_t readlnSSL(SSL *fd, void *vptr, size_t maxlen){
   ssize_t	n, rc;
   char	*ptr,c;
 
@@ -154,7 +153,7 @@ readlnSSL(SSL *fd, void *vptr, size_t maxlen)
 }
 
 /******************************/
-/* lock functions using fcntl */
+/* lock function using fcntl  */
 /******************************/
 int lock(int fd){
   struct flock lck;
@@ -167,10 +166,9 @@ int lock(int fd){
 }
   
 /********************************/
-/* unlock functions using fcntl */
+/* unlock function using fcntl  */
 /********************************/
-int unlock(int fd)
-{
+int unlock(int fd){
   struct flock lck;
 
   lck.l_type=F_UNLCK;
@@ -180,29 +178,26 @@ int unlock(int fd)
   return fcntl(fd, F_SETLK, &lck);
 }
 
-/**************************************/
-/* check NULL or point to null string */
-/**************************************/
-int isNull(const char *pStr)
-{
+/**********************************************/
+/* return true, if the pointer value is NULL  */
+/* or pointer points to null(length=0) string */
+/**********************************************/
+int isNull(const char *pStr){
   if(pStr==NULL) return TRUE;
   if(*pStr=='\0') return TRUE;
   return FALSE;
 }
 
-
-
 /**************************************************/
 /* popen with argument list                       */
 /* rootPriv: if 1, run command as root user       */
 /* type : open type "r" or "w"                    */
-/* path : command path to fork/exec               */
+/* path : path of command executing fork/exec     */
 /* ... : command arguments. last must be (char*)0 */
-/*  DO NOT SET [user entered string] in args      */
-/*  to prevent hacking                            */
+/*  If you use [user entered string] in arguments */
+/*  sanitize the string to prevent hacking.       */
 /**************************************************/
-FILE *Popenl(int rootPriv, const char *type, const char *path, ...)
-{
+FILE *Popenl(int rootPriv, const char *type, const char *path, ...){
   char	commandLine[BUFFMAXLN];
   va_list     ap;
   char *pStr;
@@ -246,11 +241,10 @@ FILE *Popenl(int rootPriv, const char *type, const char *path, ...)
 /* rootPriv: if 1, run command as root user       */
 /* path : command path to fork/exec               */
 /* ... : command arguments. last must be (char*)0 */
-/*  DO NOT SET [user entered string] in args      */
-/*  to prevent hacking                            */
+/*  If you use [user entered string] in arguments */
+/*  sanitize the string to prevent hacking.       */
 /**************************************************/
-int Systeml(int rootPriv, const char *path, ...)
-{
+int Systeml(int rootPriv, const char *path, ...){
   char	commandLine[BUFFMAXLN];
   va_list     ap;
   char *pStr;
@@ -288,14 +282,13 @@ int Systeml(int rootPriv, const char *path, ...)
 }
 
 /*************************************************/
-/* calc MD5 in hex form                          */
-/*  str: plain text to convert                   */
-/*  hexdigest: converted hex string              */
+/* calc MD5 and return in hex form               */
+/*  str: (input)plain text to convert            */
+/*  hexdigest: (output) converted hex string     */
 /*      prepare buff more or equal to 33chars    */
-/*  len: length of hexdigest buffer              */
+/*  len: (input) length of hexdigest buffer      */
 /*************************************************/
-char *md5hex(char *hexdigest, int len, char *str)
-{
+char *md5hex(char *hexdigest, int len, char *str){
   char unsigned digest[16];
   char hexcode[16]="0123456789abcdef";
   int i;
@@ -321,6 +314,7 @@ char *md5hex(char *hexdigest, int len, char *str)
 
 /*******************************************/
 /* create random session cookie            */
+/* as md5hex(processId.TimeNow)            */
 /*******************************************/
 void createCookie(char *cookie)
 {
@@ -331,11 +325,11 @@ void createCookie(char *cookie)
   md5hex(cookie, SIDMAXLN, str);
 }
 
-/*******************************************/
-/* get port number string in /etc/services */
-/*******************************************/
-char *getServicePortStr(char *servName)
-{
+/********************************************/
+/* get port number defined in /etc/services */
+/* return as string form                    */
+/********************************************/
+char *getServicePortStr(char *servName){
   struct servent *pServEnt;
   static char portStr[WORDMAXLN];
 
@@ -354,16 +348,15 @@ char *getServicePortStr(char *servName)
   return portStr;
 }
 
-/****************************************************/
-/* getenv for multiple variables                    */
-/*             after replacing '-' with '_'         */
-/*                                                  */
-/* if env = "ab cd-ef-gh ijk"                       */
-/*  repeat getenv until getting non-null value      */
-/*  getnev("ab"),getenv("cd_ef_gh"),getenv("ijk")   */
-/* if pre=TRUE convert '-' to '_' in env-var name   */
-/* if post=TRUE convert ' '|'@' to '_' in get-str   */
-/****************************************************/
+/**************************************************************/
+/* get env value from string including multiple env-var       */
+/*                                                            */
+/* if string(env) = "ab cd-ef-gh ijk"                         */
+/*  repert the search of env-var having non-null value        */
+/*  getenv("ab"),getenv("cd_ef_gh"),getenv("ijk")             */
+/* if pre=TRUE convert '-' to '_' in env-var before search    */
+/* if post=TRUE convert ' '|'@' to '_' in get-str after search*/
+/**************************************************************/
 char* getenvEx(char* env, int pre, int post){
   char work[BUFFMAXLN];
   char* envValue="";
@@ -372,29 +365,28 @@ char* getenvEx(char* env, int pre, int post){
   char* nextVar=NULL;
   int found=FALSE;
 
-  /* copy string not to destroy it */
+  /* copy string to work area */
   strlcpy(work, env, BUFFMAXLN);
 
-  /* repeat for variables */
+  /* repeat from the head to the tail of the work area */
   thisVar=nextVar=work;
-
   while(!isNull(thisVar)){
 
-    /* skip preceeding space in string */
+    /* skip preceeding spaces in string, and points the head of vairable */
     for(p=thisVar; *p==' '; p++);
     thisVar=p;
 
-    /* search space (end of this variable) */
+    /* search space (=the end of this variable) */
     for(p=thisVar; (*p!=' ' && *p!='\0'); p++);
 
-    /* prepare next variable */
-    if(*p=='\0') nextVar=p; /* end of env string */
-    else{                   /* some variales follows */
-      *p='\0';                /* set end of this variable */
-      nextVar=p+1;            /* and start of next variable */
+    /* points the next variable */
+    if(*p=='\0') nextVar=p; /* end of string */
+    else{                   /* some string follows */
+      *p='\0';                /* set termination char of this variable */
+      nextVar=p+1;            /* set the next search point */
     }
 
-    /* replace '-' in string with '_' */
+    /* if PRE is true, replace '-' in string with '_' */
     if(pre){
       for(p=thisVar; *p!='\0'; p++){
 	if(*p=='-') *p='_';
@@ -415,7 +407,7 @@ char* getenvEx(char* env, int pre, int post){
   /* getting no data */
   if(!found) return NULL;
 
-  /* convert ' ' and '@' to '_' */
+  /* if POST is true, convert ' ' and '@' to '_' */
   if(post){
     for(p=envValue; *p!='\0'; p++){
       if(*p==' ') *p='_';
@@ -432,9 +424,7 @@ char* getenvEx(char* env, int pre, int post){
 /*      By W. Richard Stevens, Published By Prentice Hall */
 /*       ftp://ftp.kohala.com/pub/rstevens/unpv12e.tar.gz */
 /**********************************************************/
-int
-tcp_connect(const char *host, const char *serv)
-{
+int tcp_connect(const char *host, const char *serv){
 	int				sockfd, n;
 	struct addrinfo	hints, *res, *ressave;
 
@@ -469,14 +459,6 @@ tcp_connect(const char *host, const char *serv)
 
 	return(sockfd);
 }
-/* end tcp_connect */
-
-/*
- * We place the wrapper function here, not in wraplib.c, because some
- * XTI programs need to include wraplib.c, and it also defines
- * a Tcp_connect() function.
- */
-
 
 /****************************************/
 /****************************************/
@@ -486,8 +468,7 @@ void CreateCookie(char *cookie){
   if(debug>1) err_msg("DEBUG:<=createCookie(%s)", cookie);  
 }
 
-char *GetServicePortStr(char *servName)
-{
+char *GetServicePortStr(char *servName){
   char *ret;
   if(debug>1) err_msg("DEBUG:=>getServicePortStr(%s)", servName);
   ret = getServicePortStr(servName);
@@ -495,8 +476,7 @@ char *GetServicePortStr(char *servName)
   return ret;
 }
 
-int Pclose(FILE *stream)
-{
+int Pclose(FILE *stream){
   int ret;
 
   if(debug>1) err_msg("DEBUG:=>pclose( )");
@@ -506,9 +486,7 @@ int Pclose(FILE *stream)
   return ret;
 }
 
-
-int Lock(int fd)
-{
+int Lock(int fd){
   int ret;
 
   if(debug>1) err_msg("DEBUG:=>lock( )");
@@ -518,9 +496,7 @@ int Lock(int fd)
   return ret;
 }
 
-
-int Unlock(int fd)
-{
+int Unlock(int fd){
   int ret;
 
   if(debug>1) err_msg("DEBUG:=>unlock( )");
@@ -530,10 +506,7 @@ int Unlock(int fd)
   return ret;
 }
 
-
-int
-Open(const char *pathname, int oflag, mode_t mode)
-{
+int Open(const char *pathname, int oflag, mode_t mode){
 	int		fd;
 
 	if ( (fd = open(pathname, oflag, mode)) == -1)
@@ -541,9 +514,7 @@ Open(const char *pathname, int oflag, mode_t mode)
 	return(fd);
 }
 
-int
-Close(int fd)
-{
+int Close(int fd){
   int ret;
 
   /*if( (ret=close(fd)) == -1)
@@ -555,9 +526,7 @@ Close(int fd)
   return ret;
 }
 
-pid_t
-Fork(void)
-{
+pid_t Fork(void){
 	pid_t	pid;
 
 	if ( (pid = fork()) == -1)
@@ -565,9 +534,7 @@ Fork(void)
 	return(pid);
 }
 
-int
-Pipe(int *fds)
-{
+int Pipe(int *fds){
   int ret;
 	if ((ret=pipe(fds)) < 0)
 		err_msg("pipe error");
@@ -575,9 +542,7 @@ Pipe(int *fds)
 	return ret;
 }
 
-void *
-Malloc(size_t size)
-{
+void *Malloc(size_t size){
 	void	*ptr;
 
 	if ( (ptr = malloc(size)) == NULL)
@@ -585,9 +550,7 @@ Malloc(size_t size)
 	return(ptr);
 }
 
-int
-Tcp_connect(const char *host, const char *serv)
-{
+int Tcp_connect(const char *host, const char *serv){
 	return(tcp_connect(host, serv));
 }
 
